//
// file: combinedplots.C
//
// macros:
//   ptPartons - plot pT for all partons in the event.
//
// Author: Reinhard Schwienhorst
//
// Modifications:
//

//----------------------------------------------------------------------------
// 
//
// plot something
int ptPartons()
{

  // the root files have already been normalized to the large non-SM 1000 samples,
  // so normalize with respect to that here.
  const float XSNorm=0.88/100000.;
  //  const float XSNorm=0.88/35000.;

  gROOT->LoadMacro("../rootutils/CombineHistos.C");

  TString plotTargetDir("../../histograms");
  TString suffix(".eps");


  TString cname="parton_tb";
  //cname+=name+PlotChoice();
  TCanvas *c1 = new TCanvas(cname.Data(), "",50,44,600,500);
  // make more space for the Y-axis title
  c1->SetLeftMargin( .21); // default is 10%
  c1->SetBottomMargin(0.15);


  TString HistoFile1="../../scripts/tb_e_SM.root";
  TFile  *file1=new TFile(HistoFile1);
  TDirectory *d1 = (TDirectory*)file1->Get("02_Histogramming_Parton/plusCharge");

  TH1F *temphist;

  TString legends[21];
  Int_t palette[21]={1,2,4, 3,1,4, 4,1,2, 3,1,2, 37,1,2, 1,2,4};
  Int_t styles[21]= {1,11,3,5, 2,1,3, 3,1,2, 4,1,2,  1,2,3, 1,2,3};
  TObjArray histospt,histoseta;
  int nplots=0;

  int rebin=5;
  int drawLine=0;       // draw histograms, no line
  bool normalize=false;

  // now add the histograms to the array:
  temphist=(TH1F*) (d1->Get("bpt"))->Clone();
  temphist->Scale(XSNorm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histospt.Add(temphist);
  temphist=(TH1F*) (d1->Get("beta"))->Clone();
  temphist->Scale(XSNorm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histoseta.Add(temphist);
  legends[nplots]="b from top";
  nplots++;

  // now add the histograms to the array:
  temphist=(TH1F*) (d1->Get("bbarpt"))->Clone();
  temphist->Scale(XSNorm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histospt.Add(temphist);
  temphist=(TH1F*) (d1->Get("bbareta"))->Clone();
  temphist->Scale(XSNorm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histoseta.Add(temphist);
  legends[nplots]="#bar{b} with top";
  nplots++;

  // now add the histograms to the array:
  temphist=(TH1F*) (d1->Get("elept"))->Clone();
  temphist->Scale(XSNorm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histospt.Add(temphist);
  temphist=(TH1F*) (d1->Get("eleeta"))->Clone();
  temphist->Scale(XSNorm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histoseta.Add(temphist);
  legends[nplots]="lepton";
  nplots++;

  // now add the histograms to the array:
  temphist=(TH1F*) (d1->Get("nupt"))->Clone();
  temphist->Scale(XSNorm*1000./temphist->GetBinWidth(1)/((double)rebin));
  histospt.Add(temphist);
  temphist=(TH1F*) (d1->Get("nueta"))->Clone();
  temphist->Scale(XSNorm*1000./temphist->GetBinWidth(1)/((double)rebin));
  //histoseta.Add(temphist);
  legends[nplots]="neutrino";
  nplots++;

 
 
  // change the y axis title in case the x axis title contains the sub-string []
  TString ytitle="d#sigma/dp_{T} [fb/5 GeV]";
  TString xtitle="p_{T} [GeV]";
  
  int legendCorner=1;
  int smoothen=0;
  double xmin=0.;
  double xmax=150.;
  double xmin_cutoff=5.;

  CombineHistos(histospt,legends,"",xtitle.Data(),ytitle.Data(),palette,styles,legendCorner,smoothen,rebin,drawLine,normalize,xmin,xmax,xmin_cutoff);

  // add some text
  TLatex *t1 = new TLatex();
  t1->SetTextFont(62);
  t1->SetTextColor(1);
  t1->SetNDC();
  t1->SetTextAlign(12);
  t1->SetTextSize(0.06);
  t1->DrawLatex(0.24,0.87,"(a)");

  // and write the plot to file
  c1->SaveAs(plotTargetDir+"/"+cname+"_pt"+suffix);

  //
  // also plot eta:
  xtitle="#eta";
  ytitle="d#sigma/d#eta [fb/0.2]";
  xmin=-4.;
  xmax=4.;
  rebin=2;
  CombineHistos(histoseta,legends,"",xtitle.Data(),ytitle.Data(),palette,styles,legendCorner,smoothen,rebin,drawLine,normalize,xmin,xmax);

  t1->DrawLatex(0.24,0.87,"(b)");

  // and write the plot to file
  c1->SaveAs(plotTargetDir+"/"+cname+"_eta"+suffix);

  //cout<<"end of plotHistogram"<<endl;
  return 0;
} // end of plotHistogram

