/******************************************************************************
 * HistogrammingMuon.hpp                                                      *
 *                                                                            *
 * Books and fills histograms                                                 *
 * Used for events passing cuts applied in other classes                      *
 *                                                                            *
 * Derived from HistoCut which is in turn derived from BaseCut                *
 *                                                                            *
 * Public Member Functions of AnalysisMain class                              *
 *    HistogrammingMuon()              -- Parameterized Constructor           *
 *    ~HistogrammingMuon()             -- Destructor                          *
 *    BookHistogram()                   -- Book histograms                    *
 *    Apply()                           -- Fill histograms only (No Cuts)     *
 *    GetCutName()                      -- Returns "HistogrammingMuon"        *
 *                                                                            *
 * Private Data Members of HistogrammingMuon class                            *
 * - lots of histograms of muon propreties                                    *
 *                                                                            *
 * History                                                                    *
 *      14 Nov 2006 - Created by R. Schwienhorst for ATLAS                    *
 *****************************************************************************/

#ifndef HistogrammingMuon_h
#define HistogrammingMuon_h

#include "single_top_analysis/HistoCut.hpp"
#include "single_top_analysis/EventContainer.hpp"

#include <string>
#include <vector>
#include <sstream>

using namespace std;


class HistogrammingMuon : public HistoCut 
{

public:

  // Parameterized Constructor
  HistogrammingMuon(EventContainer *obj);
  
  // Destructor
  ~HistogrammingMuon();

  // Get the name describing the cut
  inline std::string GetCutName() { return "HistogrammingMuon"; };

  // Book Histograms
  void BookHistogram();

  // Fill Histograms
  Bool_t Apply();
  
private:
  // Histograms declarations 
  myTH1F* _hNObj;     // Histogram of number of muons
  myTH1F* _hPtObj1;   // Muon 1 PT
  myTH1F* _hPtObj2;   // Muon 2 PT
  myTH1F* _hEtaObj1;  // Muon 1 Eta
  myTH1F* _hEtaObj2;  // Muon 2 Eta
  myTH1F* _hPhiObj1;  // Muon 1 Phi
  myTH1F* _hPhiObj2;  // Muon 2 Phi

  myTH1F *_hPt;       // Pt of all muons
  myTH1F *_hEta;      // Eta of all muons
  myTH1F *_hPhi;      // Phi of all muons
  myTH1F *_hCharge;   // Charge of all muons 
  myTH1F *_hEtCone;   // calorimeter ET in a cone for all muons 



};


#endif







