/******************************************************************************
 * Tau.hpp                                                                    *
 *                                                                            *
 * Store information about final state Taus                                   *
 *                                                                            *
 * Derived from Particle class                                                *
 *                                                                            *
 * Public Member Functions of Tau class                                       *
 *    Tau()                              -- Default Constructor               *
 *    Tau()                              -- Parameterized Constructor         *
 *    Tau()                              -- Constructor with Particle         *
 *    ~Tau()                             -- Destructor                        *
 *    Clear()                            -- Set contents to default           *
 *    Fill                               -- Fill electron from event tree     *
 *    SetSetNumTracks                    -- Set Num Tracks                    *
 *    GetSetNumTracks                    -- Set Num Tracks                    *
 *    NumTracks                          -- Set Num Tracks                    *
 *    operator+=                         -- Overload +=                       *
 *    operator+                          -- Overload +                        *
 *    operator=                          -- Overload = Particle               *
 *    operator=                          -- Overload = const Tau              *
 *    operator=                          -- Overload =                        *
 *                                                                            *
 * Private Data Members of Tau class                                          *
 *    Double_t _NumTracks                -- CAL Energy in cone around Tau     *
 *                                                                            *
 * History                                                                    *
 *      14 Nov 2006 - Created by R. Schwienhorst                              *
 *      20 Nov 2006 - Modified by P. Ryan - cleanup and reorganized           *
 *****************************************************************************/

#ifndef tau_h
#define tau_h

#include "single_top_analysis/Particle.hpp"
#include "single_top_analysis/EventTree.hpp"

class Tau: public Particle
{
public:
  // Default Constructor
  Tau();

  // Copy constructor  - Tau
  Tau(const Tau& other);

  // Copy Constructor - Particle
  Tau(const Particle& other);

  // Destructor
  ~Tau();

  // Set all contents to their defaults
  inline void Clear() { Particle::Clear(); _NumTracks = 0.0; };

  // Fill the tau from an EventTree
  void Fill(EventTree *evtr, Int_t iE);

  // Get and Set Number of tracks for this tau
  void SetNumTracks(const Double_t& eop) { _NumTracks = eop; };
  Double_t GetNumTracks() const { return _NumTracks; };
  Double_t NumTracks() const { return _NumTracks; };

  // Overloaded operators:
  // +=
  Tau& operator+=(const Tau& other);
  // +
  Tau operator+(const Tau& other);
  // = const Particle
  Tau& operator=(const Particle& other);
  // = const Tau
  Tau& operator=(const Tau& other);
  // = non-const Tau
  Tau& operator=(Tau& other);

private:
  Double_t _NumTracks;   // number of tracks

  ////////////////////////////////////////////////////////////////////////////////
  // Integrate classes into the Root system
  // Must come at end of class definition
  ClassDef(Tau,0)
  ////////////////////////////////////////////////////////////////////////////////    

};


#endif
